@@ -2,7 +2,7 @@
 package twept;
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $TIMEOUT = 2;
 local $SIG{ALRM} = sub{ die 'Force exiting, detected loop'; };
 my $STDBAK = *STDOUT;
@@ -38,12 +38,13 @@ $esc =~ s/\"/\&quot;/g;
 $esc =~ s/\n/\<br\x20\/\>/g;
 $tmp .= "<blockquote style=\"color:#009900;\">$esc</blockquote>";
 if(!run($ref,$var,$tag) && $@){
-my($l,$e) = ($@ =~ /line\x20([0-9]+)(.+)\s+$/);
-$l = $now + ($l - 1); chop $@;
-$@ =~ /^Force/ ? $@ =~ s/at\x20.+$/at\x20line\x20$now\x20or\x20after\x20that./ : $@ =~ s/at\x20\(.+$/at\x20line\x20$l$e/;
-$@ =~ s/\x22/\&quot\;/g;
+$@ =~ /^Force/ ? $@ =~ s/at\x20.+$/at\x20line\x20$now\x20or\x20after\x20that\./ : $@ =~ s/at\x20\(eval\x20[0-9]+\)\x20line\x20([0-9]+)/'at line '.($now+($1-1))/eg;
+$@ =~ s/\x22/\&quot\;/g; chop $@;
 $tmp .= qq[\n<blockquote style="padding:4px;color:#c00;background-color:#fdd;border:solid 1px #f99;font-size:80%;"><span style="font-weight:bold;">ERROR:</span> $@</blockquote>\n];
 last if $@ =~ /^Force/;
 }
-} else{ $tmp .= $tag; }
+} else{
+$tag =~ s/(?<![\\\$])(\$((::)?\w+|\[[\x22\x27]?\w+[\x22\x27]?\]|(->)?\{[\x22\x27]?\w+[\x22\x27]?\})+)/eval($1).$@/eg;
+$tmp .= $tag;
+}
 }; close TMP; *STDOUT = $STDBAK; flush $ref; print $tmp;
