@@ -9,7 +9,7 @@ our @ISA       = qw(Exporter);
 our @EXPORT    = qw(ep);
 our @EXPORT_OK = qw($VERSION $TIMEOUT);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $TIMEOUT = 2;
 
 my $STDBAK = *STDOUT;
@@ -55,14 +55,15 @@ sub ep{
       $esc =~ s/\n/\<br\x20\/\>/g;
       $tmp .= qq!<blockquote style="color:#009900;">$esc</blockquote>!;
       if(!run($ref,$var,$tag) && $@){
-        my($l,$e) = ($@ =~ /line\x20([0-9]+)(.+)\s+$/);
-        $l = $now + ($l - 1); chop $@;
-        $@ =~ /^Force/ ? $@ =~ s/at\x20.+$/at\x20line\x20$now\x20or\x20after\x20that./ : $@ =~ s/at\x20\(.+$/at\x20line\x20$l$e/;
-        $@ =~ s/\x22/\&quot\;/g;
+        $@ =~ /^Force/ ? $@ =~ s/at\x20.+$/at\x20line\x20$now\x20or\x20after\x20that\./ : $@ =~ s/at\x20\(eval\x20[0-9]+\)\x20line\x20([0-9]+)/'at line '.($now+($1-1))/eg;
+        $@ =~ s/\x22/\&quot\;/g; chop $@;
         $tmp .= qq[\n<blockquote style="padding:4px;color:#c00;background-color:#fdd;border:solid 1px #f99;font-size:80%;"><span style="font-weight:bold;">ERROR:</span> $@</blockquote>\n];
         last if $@ =~ /^Force/;
       }
-    } else{ $tmp .= $tag; }
+    } else{
+      $tag =~ s/(?<![\\\$])(\$((::)?\w+|\[[\x22\x27]?\w+[\x22\x27]?\]|(->)?\{[\x22\x27]?\w+[\x22\x27]?\})+)/eval($1).$@/eg;
+      $tmp .= $tag;
+    }
   }
   close TMP;
   *STDOUT = $STDBAK;
